# Zouqi: A Python CLI Starter Purely Built on argparse.

Zouqi (『走起』) is a CLI starter similar to [python-fire]. It is purely built on argparse.

## Installation

```plain
pip install zouqi
```

## Example

Check `example.py` for a detailed example.
